==> qt4-x11_4.3.4.orig.tar.gz: qt-x11-opensource-src-4.3.4/translations/qvfb_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>AnimationSaveWidget</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="919"/>
        <source>Record</source>
        <translation>錄影</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="718"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="720"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="738"/>
        <source>Save in MPEG format (requires netpbm package installed)</source>
        <translation>以 MPEG 格式儲存 (需要安裝 netpbm 套件)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="951"/>
        <source>Click record to begin recording.</source>
        <translation>按下「錄影」開始錄影。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="983"/>
        <source>Finished saving.</source>
        <translation>完成儲存。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="920"/>
        <source>Paused. Click record to resume, or save if done.</source>
        <translation>已暫停。按下「錄影」可以繼續，按「儲存」表示已完成。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="926"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="927"/>
        <source>Recording...</source>
        <translation>錄影中...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="967"/>
        <source>Saving... </source>
        <translation>儲存中...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="975"/>
        <source>Save animation...</source>
        <translation>儲存動畫...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="977"/>
        <source>Save canceled.</source>
        <translation>儲存已取消。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="986"/>
        <source>Save failed!</source>
        <translation>儲存失敗!</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="27"/>
        <source>Configure</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="58"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="70"/>
        <source>176x220 &quot;SmartPhone&quot;</source>
        <translation>176x220 「智慧型手機」</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="77"/>
        <source>240x320 &quot;PDA&quot;</source>
        <translation>240x320 「PDA」</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="84"/>
        <source>320x240 &quot;TV&quot; / &quot;QVGA&quot;</source>
        <translation>320x240 「TV」/「QVGA」</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="91"/>
        <source>640x480 &quot;VGA&quot;</source>
        <translation>640x480「VGA」</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="98"/>
        <source>800x600</source>
        <translation>800x600</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="105"/>
        <source>1024x768</source>
        <translation>1024x768</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="128"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="172"/>
        <source>Depth</source>
        <translation>深度</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="184"/>
        <source>1 bit monochrome</source>
        <translation>1 位元單色</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="191"/>
        <source>4 bit grayscale</source>
        <translation>4 位元灰階</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="198"/>
        <source>8 bit</source>
        <translation>8 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="205"/>
        <source>12 (16) bit</source>
        <translation>12 (16) 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="212"/>
        <source>16 bit</source>
        <translation>16 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="219"/>
        <source>18 bit</source>
        <translation>18 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="226"/>
        <source>24 bit</source>
        <translation>24 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="233"/>
        <source>32 bit</source>
        <translation>32 位元</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="253"/>
        <source>Skin</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="269"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="279"/>
        <source>Emulate touch screen (no mouse move)</source>
        <translation>模擬觸控式螢幕（沒有滑鼠移動）</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="286"/>
        <source>Emulate LCD screen (Only with fixed zoom of 3.0 times magnification)</source>
        <translation>模擬液晶螢幕（只固定縮放 3 倍）</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="314"/>
        <source>&lt;p&gt;Note that any applications using the virtual framebuffer will be terminated if you change the Size or Depth &lt;i&gt;above&lt;/i&gt;. You may freely modify the Gamma &lt;i&gt;below&lt;/i&gt;.</source>
        <translation>&lt;p&gt;注意，任何使用此虛擬 framebuffer 的應用程式在您變更大小或深度後都會被終止。不過變更底下的 Gamma 值則不會。</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="324"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="336"/>
        <source>Blue</source>
        <translation>藍</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="1219"/>
        <source>1.0</source>
        <translation>1.0</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="628"/>
        <source>Green</source>
        <translation>綠</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="920"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="1212"/>
        <source>Red</source>
        <translation>紅</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="1504"/>
        <source>Set all to 1.0</source>
        <translation>把所有的值都設為 1.0</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="1538"/>
        <source>&amp;OK</source>
        <translation>確定(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/config.ui" line="1551"/>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>QVFb</name>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="521"/>
        <source>Browse...</source>
        <translation>瀏覽...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="635"/>
        <source>Load Custom Skin...</source>
        <translation>載入自訂的外觀...</translation>
    </message>
    <message>
        <location filename="../../../../data/depot/qt/4.3/tools/qvfb/qvfb.cpp" line="636"/>
        <source>All QVFB Skins (*.skin)</source>
        <translation>所有 QVFB 外觀檔（*.skin）</translation>
    </message>
</context>
</TS>

==> qt4-x11_4.4.3.orig.tar.gz: qt-x11-opensource-src-4.4.3/translations/qvfb_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<context>
    <name>AnimationSaveWidget</name>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1028"/>
        <source>Record</source>
        <translation>錄影</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="826"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="828"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="846"/>
        <source>Save in MPEG format (requires netpbm package installed)</source>
        <translation>以 MPEG 格式儲存 (需要安裝 netpbm 套件)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1060"/>
        <source>Click record to begin recording.</source>
        <translation>按下「錄影」開始錄影。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1092"/>
        <source>Finished saving.</source>
        <translation>完成儲存。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1029"/>
        <source>Paused. Click record to resume, or save if done.</source>
        <translation>已暫停。按下「錄影」可以繼續，按「儲存」表示已完成。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1035"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1036"/>
        <source>Recording...</source>
        <translation>錄影中...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1076"/>
        <source>Saving... </source>
        <translation>儲存中...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1084"/>
        <source>Save animation...</source>
        <translation>儲存動畫...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1086"/>
        <source>Save canceled.</source>
        <translation>儲存已取消。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="1095"/>
        <source>Save failed!</source>
        <translation>儲存失敗!</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../tools/qvfb/config.ui" line="25"/>
        <source>Configure</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="72"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="93"/>
        <source>176x220 &quot;SmartPhone&quot;</source>
        <translation>176x220 「智慧型手機」</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="100"/>
        <source>240x320 &quot;PDA&quot;</source>
        <translation>240x320 「PDA」</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="107"/>
        <source>320x240 &quot;TV&quot; / &quot;QVGA&quot;</source>
        <translation>320x240 「TV」/「QVGA」</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="114"/>
        <source>640x480 &quot;VGA&quot;</source>
        <translation>640x480「VGA」</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="121"/>
        <source>800x600</source>
        <translation>800x600</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="128"/>
        <source>1024x768</source>
        <translation>1024x768</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="158"/>
        <source>Custom</source>
        <translation>自訂</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="202"/>
        <source>Depth</source>
        <translation>深度</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="223"/>
        <source>1 bit monochrome</source>
        <translation>1 位元單色</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="230"/>
        <source>4 bit grayscale</source>
        <translation>4 位元灰階</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="237"/>
        <source>8 bit</source>
        <translation>8 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="244"/>
        <source>12 (16) bit</source>
        <translation>12 (16) 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="258"/>
        <source>16 bit</source>
        <translation>16 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="265"/>
        <source>18 bit</source>
        <translation>18 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="272"/>
        <source>24 bit</source>
        <translation>24 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="279"/>
        <source>32 bit</source>
        <translation>32 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="315"/>
        <source>Skin</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="329"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="339"/>
        <source>Emulate touch screen (no mouse move)</source>
        <translation>模擬觸控式螢幕（沒有滑鼠移動）</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="346"/>
        <source>Emulate LCD screen (Only with fixed zoom of 3.0 times magnification)</source>
        <translation>模擬液晶螢幕（只固定縮放 3 倍）</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="372"/>
        <source>&lt;p&gt;Note that any applications using the virtual framebuffer will be terminated if you change the Size or Depth &lt;i&gt;above&lt;/i&gt;. You may freely modify the Gamma &lt;i&gt;below&lt;/i&gt;.</source>
        <translation>&lt;p&gt;注意，任何使用此虛擬 framebuffer 的應用程式在您變更大小或深度後都會被終止。不過變更底下的 Gamma 值則不會。</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="382"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="406"/>
        <source>Blue</source>
        <translation>藍</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1901"/>
        <source>1.0</source>
        <translation>1.0</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="902"/>
        <source>Green</source>
        <translation>綠</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1398"/>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="1894"/>
        <source>Red</source>
        <translation>紅</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2390"/>
        <source>Set all to 1.0</source>
        <translation>把所有的值都設為 1.0</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2433"/>
        <source>&amp;OK</source>
        <translation>確定(&amp;O)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="2446"/>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="251"/>
        <source>15 bit</source>
        <translation>15 位元</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/config.ui" line="286"/>
        <source>32 bit ARGB</source>
        <translation>32 位元 ARGB</translation>
    </message>
</context>
<context>
    <name>QVFb</name>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="608"/>
        <source>Browse...</source>
        <translation>瀏覽...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="734"/>
        <source>Load Custom Skin...</source>
        <translation>載入自訂的外觀...</translation>
    </message>
    <message>
        <location filename="../tools/qvfb/qvfb.cpp" line="735"/>
        <source>All QVFB Skins (*.skin)</source>
        <translation>所有 QVFB 外觀檔 (*.skin)</translation>
    </message>
</context>
</TS>
